@@ -3,7 +3,7 @@
 /*		Implementation of the symmetric block cipher modes 		*/
 /*			     Written by Ken Goldman				*/
 /*		       IBM Thomas J. Watson Research Center			*/
-/*            $Id: CryptSym.h 1618 2020-05-19 15:28:41Z kgoldman $		*/
+/*            $Id: CryptSym.h 1658 2021-01-22 23:14:01Z kgoldman $		*/
 /*										*/
 /*  Licenses and Notices							*/
 /*										*/
@@ -55,7 +55,7 @@
 /*    arising in any way out of use or reliance upon this specification or any 	*/
 /*    information herein.							*/
 /*										*/
-/*  (c) Copyright IBM Corp. and others, 2017 - 2019 				*/
+/*  (c) Copyright IBM Corp. and others, 2017 - 2021 				*/
 /*										*/
 /********************************************************************************/
 
@@ -63,25 +63,54 @@
 #ifndef CRYPTSYM_H
 #define CRYPTSYM_H
 
-typedef union tpmCryptKeySchedule_t {
 #if ALG_AES
-    tpmKeyScheduleAES           AES;
+#   define IF_IMPLEMENTED_AES(op)    op(AES, aes)
+#else
+#   define IF_IMPLEMENTED_AES(op)
 #endif
 #if ALG_SM4
-    tpmKeyScheduleSM4           SM4;
+#   define IF_IMPLEMENTED_SM4(op)    op(SM4, sm4)
+#else
+#   define IF_IMPLEMENTED_SM4(op)
 #endif
 #if ALG_CAMELLIA
-    tpmKeyScheduleCAMELLIA      CAMELLIA;
+#   define IF_IMPLEMENTED_CAMELLIA(op)    op(CAMELLIA, camellia)
+#else
+#   define IF_IMPLEMENTED_CAMELLIA(op)
 #endif
 #if ALG_TDES
-    tpmKeyScheduleTDES          TDES[3];
+#   define IF_IMPLEMENTED_TDES(op)    op(TDES, tdes)
+#else
+#   define IF_IMPLEMENTED_TDES(op)
 #endif
+
+#define FOR_EACH_SYM(op)		\
+    IF_IMPLEMENTED_AES(op)		\
+    IF_IMPLEMENTED_SM4(op)		\
+    IF_IMPLEMENTED_CAMELLIA(op)		\
+    IF_IMPLEMENTED_TDES(op)
+
+						/* libtpms added begin */
+#define FOR_EACH_SYM_WITHOUT_TDES(op)	\
+    IF_IMPLEMENTED_AES(op)		\
+    IF_IMPLEMENTED_SM4(op)		\
+    IF_IMPLEMENTED_CAMELLIA(op)			/* libtpms added end */
+
+/* Macros for creating the key schedule union */
+
+#define     KEY_SCHEDULE(SYM, sym)      tpmKeySchedule##SYM sym;
+//#define     TDES    DES[3]			/* libtpms commented */
+typedef union tpmCryptKeySchedule_t {
+    FOR_EACH_SYM_WITHOUT_TDES(KEY_SCHEDULE)	/* libtpms changed from FOR_EACH_SYM */
+    tpmKeyScheduleTDES  tdes[3];		/* libtpms added */
+
 #if SYMMETRIC_ALIGNMENT == 8
     uint64_t            alignment;
 #else
     uint32_t            alignment;
 #endif
 } tpmCryptKeySchedule_t;
+
 /* Each block cipher within a library is expected to conform to the same calling conventions with
    three parameters (keySchedule, in, and out) in the same order. That means that all algorithms
    would use the same order of the same parameters. The code is written assuming the (keySchedule,
@@ -94,56 +123,20 @@ typedef union tpmCryptKeySchedule_t {
     encrypt(SWIZZLE(keySchedule, in, out))
 #   define DECRYPT(keySchedule, in, out)	\
     decrypt(SWIZZLE(keySchedule, in, out))
+
 /* Note that the macros rely on encrypt as local values in the functions that use these
    macros. Those parameters are set by the macro that set the key schedule to be used for the
    call. */
-#define ENCRYPT_CASE(ALG)						\
+
+#define ENCRYPT_CASE(ALG, alg)						\
     case TPM_ALG_##ALG:							\
-    TpmCryptSetEncryptKey##ALG(key, keySizeInBits, &keySchedule.ALG);	\
+    TpmCryptSetEncryptKey##ALG(key, keySizeInBits, &keySchedule.alg);	\
     encrypt = (TpmCryptSetSymKeyCall_t)TpmCryptEncrypt##ALG;		\
     break;
-#define DECRYPT_CASE(ALG)						\
+#define DECRYPT_CASE(ALG, alg)						\
     case TPM_ALG_##ALG:							\
-    TpmCryptSetDecryptKey##ALG(key, keySizeInBits, &keySchedule.ALG);	\
+    TpmCryptSetDecryptKey##ALG(key, keySizeInBits, &keySchedule.alg);	\
     decrypt = (TpmCryptSetSymKeyCall_t)TpmCryptDecrypt##ALG;		\
     break;
-#if ALG_AES
-#define ENCRYPT_CASE_AES    ENCRYPT_CASE(AES)
-#define DECRYPT_CASE_AES    DECRYPT_CASE(AES)
-#else
-#define ENCRYPT_CASE_AES
-#define DECRYPT_CASE_AES
-#endif
-#if ALG_SM4
-#define ENCRYPT_CASE_SM4    ENCRYPT_CASE(SM4)
-#define DECRYPT_CASE_SM4    DECRYPT_CASE(SM4)
-#else
-#define ENCRYPT_CASE_SM4
-#define DECRYPT_CASE_SM4
-#endif
-#if ALG_CAMELLIA
-#define ENCRYPT_CASE_CAMELLIA    ENCRYPT_CASE(CAMELLIA)
-#define DECRYPT_CASE_CAMELLIA    DECRYPT_CASE(CAMELLIA)
-#else
-#define ENCRYPT_CASE_CAMELLIA
-#define DECRYPT_CASE_CAMELLIA
-#endif
-#if ALG_TDES
-#define ENCRYPT_CASE_TDES    ENCRYPT_CASE(TDES)
-#define DECRYPT_CASE_TDES    DECRYPT_CASE(TDES)
-#else
-#define ENCRYPT_CASE_TDES
-#define DECRYPT_CASE_TDES
-#endif
-/* For each algorithm the case will either be defined or null. */
-#define     SELECT(direction)					    \
-    switch(algorithm)						    \
-	{								\
-	    direction##_CASE_AES					\
-	    direction##_CASE_SM4					\
-            direction##_CASE_CAMELLIA					\
-	    direction##_CASE_TDES					\
-	  default:							\
-		FAIL(FATAL_ERROR_INTERNAL);				\
-	}
+
 #endif
